@@ -692,10 +692,6 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	    STRLEN len = strlen(col);
 #endxtract
 	    if (ChopBlanks) {
-		while(len && isspace(*col)) {
-		    ++col;
-		    --len;
-		}
 		while(len && isspace(col[len-1])) {
 		    --len;
 		}
@@ -1013,7 +1009,9 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
 	 *  dbd_st_destroy and dbd_st_execute.
 	 */
 	if (cacheit) {
-	    imp_sth->av_attr[what] = (AV*) SvREFCNT_inc((SV*)av);
+	    imp_sth->av_attr[what] = av;
+	} else {
+	    return sv_2mortal(newRV_noinc((SV*) av));
 	}
     }
 
